SymbolSet

Struct SymbolSet 

pub struct SymbolSet {
    pub pointer: char,
    pub arrow: char,
    pub completed: char,
    pub middle_dot: char,
    pub cross: char,
    pub box_top_right: char,
    pub box_top_left: char,
    pub box_bottom_right: char,
    pub box_bottom_left: char,
    pub box_horizontal: char,
    pub box_vertical: char,
}
The various special symbols used by the prompts during rendering.

Fields

pointer: char

Used to point to a special item.

For example, this is used in the various list prompts to show the currently hovered item.

arrow: char

Generic decoration mark which points to the right.

For example, this is used in the prompts when there is no hint between the question and the answer.

completed: char

Decoration to show when a question is completed.

For example, this is replaces the question mark when the question is answered.

middle_dot: char

Decoration to add some spacing without leaving it empty.

For example, this is used by prompts to separate an answered question from its answer.

cross: char

A symbol to indicate something being wrong.

For example, this is used by prompts if validation fails.

box_top_right: char

Character for the top right corner of a box.

box_top_left: char

Character for the top left corner of a box.

box_bottom_right: char

Character for the bottom right corner of a box.

box_bottom_left: char

Character for the bottom left corner of a box.

box_horizontal: char

Character for the horizontal edge of a box.

box_vertical: char

Character for the vertical edge of a box.